@@ -1,4 +1,5 @@
-/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
+   Copyright (C) 2009-2011, Stefan Hacker <dd0t@users.sourceforge.net>
 
    All rights reserved.
 
@@ -28,14 +29,12 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#ifndef _ACLEDITOR_H
-#define _ACLEDITOR_H
+#ifndef ACLEDITOR_H_
+#define ACLEDITOR_H_
 
-#include "mumble_pch.hpp"
-#include "Message.h"
 #include "ACL.h"
 #include "Group.h"
-#include "ClientUser.h"
+#include "Mumble.pb.h"
 
 #include "ui_ACLEditor.h"
 
@@ -132,7 +131,4 @@ class ACLEditor : public QDialog, public Ui::ACLEditor {
 		void on_qpbGroupInheritRemove_clicked();
 };
 
-#else
-class ACLEditor;
-class ACLTabWidget;
 #endif
