@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2010, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -28,10 +28,12 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#ifndef _AUDIOSTATS_H
-#define _AUDIOSTATS_H
+#ifndef AUDIOSTATS_H_
+#define AUDIOSTATS_H_
 
-#include "mumble_pch.hpp"
+#include <QtCore/QList>
+#include <QtCore/QTimer>
+#include <QtGui/QWidget>
 
 class AudioBar : public QWidget {
 	private:
@@ -47,19 +49,17 @@ class AudioBar : public QWidget {
 		QColor qcBelow, qcInside, qcAbove;
 
 		QList<QColor> qlReplacableColors;
-		QList<QBrush> qlReplacementBrushes;
+		QList<Qt::BrushStyle> qlReplacementBrushes;
 };
 
-class AudioEchoWidget : public QGLWidget {
+class AudioEchoWidget : public QWidget {
 	private:
 		Q_OBJECT
 		Q_DISABLE_COPY(AudioEchoWidget)
 	public:
 		AudioEchoWidget(QWidget *parent);
-	protected:
-		void initializeGL();
-		void resizeGL(int w, int h);
-		void paintGL();
+	protected slots:
+		void paintEvent(QPaintEvent *event);
 };
 
 class AudioNoiseWidget : public QWidget {
@@ -83,6 +83,7 @@ class AudioStats : public QDialog, public Ui::AudioStats {
 		bool bTalking;
 	public:
 		AudioStats(QWidget *parent);
+		~AudioStats();
 	public slots:
 		void on_Tick_timeout();
 };
