@@ -93,18 +93,25 @@ ServerView::ServerView(QWidget *p) : QTreeWidget(p) {
 	siLAN = NULL;
 #endif
 
-	siPublic = new ServerItem(tr("Public Internet"), ServerItem::PublicType);
-	siPublic->setChildIndicatorPolicy(QTreeWidgetItem::ShowIndicator);
-	addTopLevelItem(siPublic);
-
-	siPublic->setExpanded(false);
-
-	qmContinentNames.insert(QLatin1String("af"), tr("Africa"));
-	qmContinentNames.insert(QLatin1String("as"), tr("Asia"));
-	qmContinentNames.insert(QLatin1String("na"), tr("North America"));
-	qmContinentNames.insert(QLatin1String("sa"), tr("South America"));
-	qmContinentNames.insert(QLatin1String("eu"), tr("Europe"));
-	qmContinentNames.insert(QLatin1String("oc"), tr("Oceania"));
+	if (!g.s.disablePublicList) {
+		siPublic = new ServerItem(tr("Public Internet"), ServerItem::PublicType);
+		siPublic->setChildIndicatorPolicy(QTreeWidgetItem::ShowIndicator);
+		addTopLevelItem(siPublic);
+		
+		
+		siPublic->setExpanded(false);
+	
+		qmContinentNames.insert(QLatin1String("af"), tr("Africa"));
+		qmContinentNames.insert(QLatin1String("as"), tr("Asia"));
+		qmContinentNames.insert(QLatin1String("na"), tr("North America"));
+		qmContinentNames.insert(QLatin1String("sa"), tr("South America"));
+		qmContinentNames.insert(QLatin1String("eu"), tr("Europe"));
+		qmContinentNames.insert(QLatin1String("oc"), tr("Oceania"));
+	} else {
+		qWarning()<< "Public list disabled";
+		
+		siPublic = NULL;
+	}
 }
 
 ServerView::~ServerView() {
@@ -771,6 +778,7 @@ ConnectDialog::ConnectDialog(QWidget *p, bool autoconnect) : QDialog(p), bAutoCo
 	connect(qpbAdd, SIGNAL(clicked()), qaFavoriteAddNew, SIGNAL(triggered()));
 	qdbbButtonBox->addButton(qpbAdd, QDialogButtonBox::ActionRole);
 
+	
 	qpbEdit = new QPushButton(tr("&Edit..."), this);
 	qpbEdit->setEnabled(false);
 	qpbEdit->setDefault(false);
@@ -778,6 +786,9 @@ ConnectDialog::ConnectDialog(QWidget *p, bool autoconnect) : QDialog(p), bAutoCo
 	connect(qpbEdit, SIGNAL(clicked()), qaFavoriteEdit, SIGNAL(triggered()));
 	qdbbButtonBox->addButton(qpbEdit, QDialogButtonBox::ActionRole);
 	
+	qpbAdd->setHidden(g.s.disableConnectDialogEditing);
+	qpbEdit->setHidden(g.s.disableConnectDialogEditing);
+	
 	qtwServers->sortItems(1, Qt::AscendingOrder);
 	qtwServers->header()->setResizeMode(0, QHeaderView::Stretch);
 	qtwServers->header()->setResizeMode(1, QHeaderView::ResizeToContents);
@@ -849,8 +860,11 @@ ConnectDialog::ConnectDialog(QWidget *p, bool autoconnect) : QDialog(p), bAutoCo
 	connect(qusSocket4, SIGNAL(readyRead()), this, SLOT(udpReply()));
 	connect(qusSocket6, SIGNAL(readyRead()), this, SLOT(udpReply()));
 
-	if (qtwServers->siFavorite->isHidden() && (!qtwServers->siLAN || qtwServers->siLAN->isHidden()))
+	if (qtwServers->siFavorite->isHidden()
+	    && (!qtwServers->siLAN || qtwServers->siLAN->isHidden())
+	    && qtwServers->siPublic != NULL) {
 		qtwServers->siPublic->setExpanded(true);
+	}
 
 	iPingIndex = -1;
 	qtPingTick->start(50);
@@ -1078,20 +1092,30 @@ void ConnectDialog::on_qtwServers_customContextMenuRequested(const QPoint &mpos)
 	ServerItem *si = static_cast<ServerItem *>(qtwServers->itemAt(mpos));
 	qmPopup->clear();
 
-	if (si && si->bParent)
+	if (si != NULL && si->bParent) {
 		si = NULL;
-
-	if (si && (si->itType == ServerItem::FavoriteType)) {
-		qmPopup->addAction(qaFavoriteEdit);
-		qmPopup->addAction(qaFavoriteRemove);
-	} else if (si) {
-		qmPopup->addAction(qaFavoriteAdd);
 	}
-	if (si && ! si->qsUrl.isEmpty())
-		qmPopup->addAction(qaUrl);
+	
+	if (si != NULL) {
 
-	if (! qmPopup->isEmpty())
+		if (!g.s.disableConnectDialogEditing) {
+			if (si->itType == ServerItem::FavoriteType) {
+				qmPopup->addAction(qaFavoriteEdit);
+				qmPopup->addAction(qaFavoriteRemove);
+			} else if (si) {
+				qmPopup->addAction(qaFavoriteAdd);
+			}
+		}
+		
+		if (!si->qsUrl.isEmpty()) {
+			qmPopup->addAction(qaUrl);
+		}
+	}
+	
+	if (! qmPopup->isEmpty()) {
 		qmPopup->addSeparator();
+	}
+	
 	qmPopup->addMenu(qmFilters);
 
 	qmPopup->popup(qtwServers->viewport()->mapToGlobal(mpos), NULL);
@@ -1118,7 +1142,7 @@ void ConnectDialog::on_qtwServers_currentItemChanged(QTreeWidgetItem *item, QTre
 }
 
 void ConnectDialog::on_qtwServers_itemExpanded(QTreeWidgetItem *item) {
-	if (item == qtwServers->siPublic) {
+	if (qtwServers->siPublic != NULL && item == qtwServers->siPublic) {
 		initList();
 		fillList();
 	}
