@@ -90,12 +90,8 @@ OverlayClient::~OverlayClient() {
 	delete qgpiCursor;
 	delete qgpiLogo;
 
-	qlsSocket->disconnectFromServer();
-	if (!qlsSocket->waitForDisconnected(1000)) {
-		qDebug() << "OverlayClient: Failed to cleanly disconnect: " << qlsSocket->errorString();
-		qlsSocket->abort();
-	}
-	
+	qlsSocket->disconnect();
+	qlsSocket->abort();
 	qlsSocket->deleteLater();
 
 	ougUsers.reset();
