@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
    Copyright (C) 2007, Stefan Gehn <mETz AT gehn DOT net>
 
    All rights reserved.
@@ -29,6 +29,8 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
+#include "mumble_pch.hpp"
+
 #include "PAAudio.h"
 #include "Global.h"
 
@@ -79,10 +81,8 @@ void PAInit::initialize() {
 }
 
 void PAInit::destroy() {
-	if (pairReg)
-		delete pairReg;
-	if (paorReg)
-		delete paorReg;
+	delete pairReg;
+	delete paorReg;
 	if (bInit) {
 		PaError err = Pa_Terminate();
 		if (err != paNoError) {
