@@ -33,6 +33,8 @@
 
 #include <QtGui/QTextEdit>
 
+class LogDocument;
+
 class RichTextHtmlEdit : public QTextEdit {
 	private:
 		Q_OBJECT
@@ -41,6 +43,8 @@ class RichTextHtmlEdit : public QTextEdit {
 		void insertFromMimeData(const QMimeData *source);
 	public:
 		RichTextHtmlEdit(QWidget *p);
+	private:
+		LogDocument *m_document;
 };
 
 #include "ui_RichTextEditor.h"
@@ -89,4 +93,9 @@ class RichTextEditor : public QTabWidget, Ui::RichTextEditor {
 		void onCurrentChanged(int);
 };
 
+class RichTextImage {
+	public:
+		static bool isValidImage(const QByteArray &buf, QByteArray &fmt);
+};
+
 #endif
