@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2009, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -28,18 +28,39 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#ifndef _SERVERHANDLER_H
-#define _SERVERHANDLER_H
+#ifndef SERVERHANDLER_H_
+#define SERVERHANDLER_H_
+
+#include <boost/accumulators/accumulators.hpp>
+#include <boost/accumulators/statistics/stats.hpp>
+#include <boost/accumulators/statistics/mean.hpp>
+#include <boost/accumulators/statistics/variance.hpp>
+#include <boost/shared_ptr.hpp>
+
+#include <QtCore/QEvent>
+#include <QtCore/QMutex>
+#include <QtCore/QObject>
+#include <QtCore/QThread>
+#include <QtCore/QTimer>
+#include <QtNetwork/QHostAddress>
+#include <QtNetwork/QSslCipher>
+#include <QtNetwork/QSslError>
+
+#ifdef Q_OS_WIN
+#include <windows.h>
+#endif
 
 #define SERVERSEND_EVENT 3501
 
-#include "mumble_pch.hpp"
 #include "Timer.h"
 #include "Message.h"
-#include "PacketDataStream.h"
+#include "Mumble.pb.h"
 
 class Connection;
 class Message;
+class PacketDataStream;
+class QUdpSocket;
+class VoiceRecorder;
 
 class ServerHandlerMessageEvent : public QEvent {
 	public:
@@ -59,9 +80,9 @@ class ServerHandler : public QThread {
 		QString qsHostName;
 		QString qsUserName;
 		QString qsPassword;
-		QString qsDigest;
 		unsigned short usPort;
 		bool bUdp;
+		bool bStrong;
 
 #ifdef Q_OS_WIN
 		HANDLE hQoS;
@@ -81,6 +102,7 @@ class ServerHandler : public QThread {
 		QSslCipher qscCipher;
 		ConnectionPtr cConnection;
 		QByteArray qbaDigest;
+		boost::shared_ptr<VoiceRecorder> recorder;
 
 		unsigned int uiVersion;
 		QString qsRelease;
@@ -92,7 +114,8 @@ class ServerHandler : public QThread {
 		ServerHandler();
 		~ServerHandler();
 		void setConnectionInfo(const QString &host, unsigned short port, const QString &username, const QString &pw);
-		void getConnectionInfo(QString &host, unsigned short &port, QString &username, QString &pw);
+		void getConnectionInfo(QString &host, unsigned short &port, QString &username, QString &pw) const;
+		bool isStrong() const;
 		void customEvent(QEvent *evt);
 
 		void sendProtoMessage(const ::google::protobuf::Message &msg, unsigned int msgType);
@@ -102,6 +125,25 @@ class ServerHandler : public QThread {
 		MUMBLE_MH_ALL
 #undef MUMBLE_MH_MSG
 
+		void requestUserStats(unsigned int uiSession, bool statsOnly);
+		void joinChannel(unsigned int channel);
+		void createChannel(unsigned int parent_, const QString &name, const QString &description, unsigned int position, bool temporary);
+		void setTexture(const QByteArray &qba);
+		void requestBanList();
+		void requestUserList();
+		void requestACL(unsigned int channel);
+		void registerUser(unsigned int uiSession);
+		void kickBanUser(unsigned int uiSession, const QString &reason, bool ban);
+		void sendUserTextMessage(unsigned int uiSession, const QString &message_);
+		void sendChannelTextMessage(unsigned int channel, const QString &message_, bool tree);
+		void setUserComment(unsigned int uiSession, const QString &comment);
+		void removeChannel(unsigned int channel);
+		void addChannelLink(unsigned int channel, unsigned int link);
+		void removeChannelLink(unsigned int channel, unsigned int link);
+		void requestChannelPermissions(unsigned int channel);
+		void setSelfMuteDeafState(bool mute, bool deaf);
+		void announceRecordingState(bool recording);
+
 		void disconnect();
 		void run();
 	signals:
@@ -115,9 +157,10 @@ class ServerHandler : public QThread {
 		void serverConnectionClosed(QAbstractSocket::SocketError, const QString &);
 		void setSslErrors(const QList<QSslError> &);
 		void udpReady();
+	public slots:
 		void sendPing();
 };
 
-#else
-class ServerHandler;
+typedef boost::shared_ptr<ServerHandler> ServerHandlerPtr;
+
 #endif
