@@ -235,6 +235,7 @@ struct Settings {
 	bool bSuppressMacEventTapWarning;
 	bool bEnableEvdev;
 	bool bEnableXInput2;
+	bool bEnableXboxInput;
 	QList<Shortcut> qlShortcuts;
 
 	enum MessageLog { LogNone = 0x00, LogConsole = 0x01, LogTTS = 0x02, LogBalloon = 0x04, LogSoundfile = 0x08};
@@ -308,9 +309,17 @@ struct Settings {
 	RecordingMode rmRecordingMode;
 	int iRecordingFormat;
 
-	// Codec kill-switch
+	// Special configuration options not exposed to UI
+	
+	/// Codec kill-switch
 	bool bDisableCELT;
-
+	
+	/// Disables the "Public Internet" section in the connect dialog if set.
+	bool disablePublicList;
+	
+	/// Removes the add and edit options in the connect dialog if set.
+	bool disableConnectDialogEditing;
+	
 	// Config updates
 	unsigned int uiUpdateCounter;
 
