@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2010, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -28,16 +28,26 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#ifndef _USEREDIT_H
-#define _USEREDIT_H
+#ifndef USEREDIT_H_
+#define USEREDIT_H_
 
-#include "mumble_pch.hpp"
-#include "ui_UserEdit.h"
 #include "Message.h"
 
+#include "ui_UserEdit.h"
+
+namespace MumbleProto {
+class UserList;
+}
+
+class UserEditListItem : public QListWidgetItem {
+	public:
+		UserEditListItem(const QString &username, const int userid);
+		bool operator<(const QListWidgetItem & other) const;
+};
+
 class UserEdit : public QDialog, public Ui::UserEdit {
 	private:
-		Q_OBJECT;
+		Q_OBJECT
 		Q_DISABLE_COPY(UserEdit)
 	protected:
 		QMap<int, QString> qmUsers;
