@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2010, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -28,15 +28,31 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "Server.h"
-#include "ServerUser.h"
+#include "murmur_pch.h"
+
 #include "Channel.h"
 #include "Group.h"
 #include "Meta.h"
+#include "Server.h"
 #include "ServerDB.h"
+#include "ServerUser.h"
 #include "Version.h"
 
-void Server::setUserState(User *pUser, Channel *cChannel, bool mute, bool deaf, bool suppressed, const QString &comment) {
+/*!
+  \fn void Server::setTempGroups(int userid, Channel *cChannel, const QStringList &groups)
+  Sets the list of temporary groups the given userid is a member of. If no channel is given root will
+  be targeted.
+
+  If userid is negative the absolute value is a session id. If it is positive it is a registration id.
+*/
+
+/*!
+  \fn void Server::clearTempGroups(User *user, Channel *cChannel = NULL, bool recurse = true)
+  Clears temporary group memberships for the given User. If no channel is given root will be targeted.
+  If recursion is activated all temporary memberships in related channels will also be cleared.
+*/
+
+void Server::setUserState(User *pUser, Channel *cChannel, bool mute, bool deaf, bool suppressed, bool prioritySpeaker, const QString& name, const QString &comment) {
 	bool changed = false;
 
 	if (deaf)
@@ -58,6 +74,10 @@ void Server::setUserState(User *pUser, Channel *cChannel, bool mute, bool deaf,
 		changed = true;
 		mpus.set_suppress(suppressed);
 	}
+	if (prioritySpeaker != pUser->bPrioritySpeaker) {
+		changed = true;
+		mpus.set_priority_speaker(prioritySpeaker);
+	}
 	if (comment != pUser->qsComment) {
 		changed = true;
 		mpus.set_comment(u8(comment));
@@ -67,10 +87,16 @@ void Server::setUserState(User *pUser, Channel *cChannel, bool mute, bool deaf,
 			setInfo(pUser->iId, info);
 		}
 	}
+	if (name != pUser->qsName) {
+		changed = true;
+		mpus.set_name(u8(name));
+	}
 
 	pUser->bDeaf = deaf;
 	pUser->bMute = mute;
 	pUser->bSuppress = suppressed;
+	pUser->bPrioritySpeaker = prioritySpeaker;
+	pUser->qsName = name;
 	hashAssign(pUser->qsComment, pUser->qbaCommentHash, comment);
 
 	if (cChannel != pUser->cChannel) {
@@ -113,6 +139,10 @@ bool Server::setChannelState(Channel *cChannel, Channel *cParent, const QString
 			p = p->cParent;
 		}
 
+		if (!canNest(cParent, cChannel)) {
+			return false;
+		}
+
 		cChannel->cParent->removeChannel(cChannel);
 		cParent->addChannel(cChannel);
 
@@ -126,7 +156,7 @@ bool Server::setChannelState(Channel *cChannel, Channel *cParent, const QString
 
 	if (links != oldset) {
 		// Remove
-		foreach(Channel *l, links) {
+		foreach(Channel *l, oldset) {
 			if (! links.contains(l)) {
 				removeLink(cChannel, l);
 				mpcs.add_links_remove(l->iId);
@@ -207,13 +237,16 @@ void Server::sendTextMessage(Channel *cChannel, ServerUser *pUser, bool tree, co
 	}
 }
 
-void Server::setTempGroups(int userid, Channel *cChannel, const QStringList &groups) {
+void Server::setTempGroups(int userid, int sessionId, Channel *cChannel, const QStringList &groups) {
 	if (! cChannel)
 		cChannel = qhChannels.value(0);
 
 	Group *g;
-	foreach(g, cChannel->qhGroups)
+	foreach(g, cChannel->qhGroups) {
 		g->qsTemporary.remove(userid);
+		if (sessionId != 0)
+			g->qsTemporary.remove(- sessionId);
+	}
 
 	QString gname;
 	foreach(gname, groups) {
@@ -222,6 +255,8 @@ void Server::setTempGroups(int userid, Channel *cChannel, const QStringList &gro
 			g = new Group(cChannel, gname);
 		}
 		g->qsTemporary.insert(userid);
+		if (sessionId != 0)
+			g->qsTemporary.insert(- sessionId);
 	}
 
 	User *p = qhUsers.value(userid);
@@ -229,13 +264,34 @@ void Server::setTempGroups(int userid, Channel *cChannel, const QStringList &gro
 		clearACLCache(p);
 }
 
+void Server::clearTempGroups(User *user, Channel *cChannel, bool recurse) {
+	QList<Channel*> qlChans;
+	if (! cChannel)
+		cChannel = qhChannels.value(0);
+
+	qlChans.append(cChannel);
+
+	while (!qlChans.isEmpty()) {
+		Channel *chan = qlChans.takeLast();
+		Group *g;
+		foreach(g, chan->qhGroups) {
+			g->qsTemporary.remove(user->iId);
+			g->qsTemporary.remove(- static_cast<int>(user->uiSession));
+		}
+
+		if (recurse)
+			qlChans << chan->qlChannels;
+	}
+
+	clearACLCache(user);
+}
 
 void Server::connectAuthenticator(QObject *obj) {
 	connect(this, SIGNAL(registerUserSig(int &, const QMap<int, QString> &)), obj, SLOT(registerUserSlot(int &, const QMap<int, QString> &)));
 	connect(this, SIGNAL(unregisterUserSig(int &, int)), obj, SLOT(unregisterUserSlot(int &, int)));
 	connect(this, SIGNAL(getRegisteredUsersSig(const QString &, QMap<int, QString> &)), obj, SLOT(getRegisteredUsersSlot(const QString &, QMap<int, QString> &)));
 	connect(this, SIGNAL(getRegistrationSig(int &, int, QMap<int, QString> &)), obj, SLOT(getRegistrationSlot(int &, int, QMap<int, QString> &)));
-	connect(this, SIGNAL(authenticateSig(int &, QString &, const QList<QSslCertificate> &, const QString &, bool, const QString &)), obj, SLOT(authenticateSlot(int &, QString &, const QList<QSslCertificate> &, const QString &, bool, const QString &)));
+	connect(this, SIGNAL(authenticateSig(int &, QString &, int, const QList<QSslCertificate> &, const QString &, bool, const QString &)), obj, SLOT(authenticateSlot(int &, QString &, int, const QList<QSslCertificate> &, const QString &, bool, const QString &)));
 	connect(this, SIGNAL(setInfoSig(int &, int, const QMap<int, QString> &)), obj, SLOT(setInfoSlot(int &, int, const QMap<int, QString> &)));
 	connect(this, SIGNAL(setTextureSig(int &, int, const QByteArray &)), obj, SLOT(setTextureSlot(int &, int, const QByteArray &)));
 	connect(this, SIGNAL(idToNameSig(QString &, int)), obj, SLOT(idToNameSlot(QString &, int)));
@@ -248,7 +304,7 @@ void Server::disconnectAuthenticator(QObject *obj) {
 	disconnect(this, SIGNAL(unregisterUserSig(int &, int)), obj, SLOT(unregisterUserSlot(int &, int)));
 	disconnect(this, SIGNAL(getRegisteredUsersSig(const QString &, QMap<int, QString> &)), obj, SLOT(getRegisteredUsersSlot(const QString &, QMap<int, QString> &)));
 	disconnect(this, SIGNAL(getRegistrationSig(int &, int, QMap<int, QString> &)), obj, SLOT(getRegistrationSlot(int &, int, QMap<int, QString> &)));
-	disconnect(this, SIGNAL(authenticateSig(int &, QString &, const QList<QSslCertificate> &, const QString &, bool, const QString &)), obj, SLOT(authenticateSlot(int &, QString &, const QList<QSslCertificate> &, const QString &, bool, const QString &)));
+	disconnect(this, SIGNAL(authenticateSig(int &, QString &, int, const QList<QSslCertificate> &, const QString &, bool, const QString &)), obj, SLOT(authenticateSlot(int &, QString &, int, const QList<QSslCertificate> &, const QString &, bool, const QString &)));
 	disconnect(this, SIGNAL(setInfoSig(int &, int, const QMap<int, QString> &)), obj, SLOT(setInfoSlot(int &, int, const QMap<int, QString> &)));
 	disconnect(this, SIGNAL(setTextureSig(int &, int, const QByteArray &)), obj, SLOT(setTextureSlot(int &, int, const QByteArray &)));
 	disconnect(this, SIGNAL(idToNameSig(QString &, int)), obj, SLOT(idToNameSlot(QString &, int)));
@@ -258,6 +314,7 @@ void Server::disconnectAuthenticator(QObject *obj) {
 
 void Server::connectListener(QObject *obj) {
 	connect(this, SIGNAL(userStateChanged(const User *)), obj, SLOT(userStateChanged(const User *)));
+	connect(this, SIGNAL(userTextMessage(const User *, const TextMessage &)), obj, SLOT(userTextMessage(const User *, const TextMessage &)));
 	connect(this, SIGNAL(userConnected(const User *)), obj, SLOT(userConnected(const User *)));
 	connect(this, SIGNAL(userDisconnected(const User *)), obj, SLOT(userDisconnected(const User *)));
 	connect(this, SIGNAL(channelStateChanged(const Channel *)), obj, SLOT(channelStateChanged(const Channel *)));
@@ -267,6 +324,7 @@ void Server::connectListener(QObject *obj) {
 
 void Server::disconnectListener(QObject *obj) {
 	disconnect(this, SIGNAL(userStateChanged(const User *)), obj, SLOT(userStateChanged(const User *)));
+	disconnect(this, SIGNAL(userTextMessage(const User *, const TextMessage &)), obj, SLOT(userTextMessage(const User *, const TextMessage &)));
 	disconnect(this, SIGNAL(userConnected(const User *)), obj, SLOT(userConnected(const User *)));
 	disconnect(this, SIGNAL(userDisconnected(const User *)), obj, SLOT(userDisconnected(const User *)));
 	disconnect(this, SIGNAL(channelStateChanged(const Channel *)), obj, SLOT(channelStateChanged(const Channel *)));
@@ -282,10 +340,5 @@ void Meta::connectListener(QObject *obj) {
 void Meta::getVersion(int &major, int &minor, int &patch, QString &string) {
 	string = QLatin1String(MUMBLE_RELEASE);
 	major = minor = patch = 0;
-	QRegExp rx(QLatin1String("(\\d+)\\.(\\d+)\\.(\\d+)"));
-	if (rx.exactMatch(QLatin1String(MUMTEXT(MUMBLE_VERSION_STRING)))) {
-		major = rx.cap(1).toInt();
-		minor = rx.cap(2).toInt();
-		patch = rx.cap(3).toInt();
-	}
+	MumbleVersion::get(&major, &minor, &patch);
 }
